@@ -2,9 +2,6 @@
 
 bool DateTime::setSeconds(int seconds)
 {
-    if (!d_ok)
-        return false;
-
     struct tm tmStruct = d_tm;
     tmStruct.tm_sec = seconds;
 
