@@ -5,7 +5,11 @@ SocketBase::SocketBase(string const &host, uint16_t port)
     InetAddress(host, port)
 {
     d_sock = ::socket(AF_INET, SOCK_STREAM, 0);   // 0: protocol, should be 0
-
-    if (d_sock < 0)
-        d_msg = "SocketBase::SocketBase(host, port)";
+    d_msg = d_sock < 0 ? "SocketBase::SocketBase(host, port)" : 0;
 }
+
+
+
+
+
+
